@@ -59,9 +59,8 @@ from lino.core.modeltools import is_valid_email
 
 from lino.utils.daemoncommand import DaemonCommand
 
-from lino.utils.niss import is_valid_niss
+from lino.utils.ssin import is_valid_ssin
 
-#~ from lino.apps.pcsw.models  import is_valid_niss
 
 #~ from lino_welfare.modlib.pcsw import models as pcsw
 #~ from lino_welfare.modlib.pcsw.management.commands.initdb_tim import ADR_id
@@ -177,13 +176,13 @@ def pxs2client(row,person):
     par2client(row,person)    
         
     if row.has_key('CARDTYPE'):
-        #~ row.card_type = pcsw.BeIdCardType.items_dict.get(row['CARDTYPE'].strip(),'')
+        #~ row.card_type = pcsw.BeIdCardTypes.items_dict.get(row['CARDTYPE'].strip(),'')
         #~ from lino.apps.pcsw import models as pcsw
         if row['CARDTYPE'] == 0:
-            #~ person.card_type = pcsw.BeIdCardType.blank_item
+            #~ person.card_type = pcsw.BeIdCardTypes.blank_item
             person.card_type = ''
         else:
-            person.card_type = pcsw.BeIdCardType.get_by_value(str(row['CARDTYPE']))
+            person.card_type = pcsw.BeIdCardTypes.get_by_value(str(row['CARDTYPE']))
             
     if row['IDMUT']:
         checkcc(person,ADR_id(row['IDMUT']),CCTYPE_HEALTH_INSURANCE)
@@ -272,11 +271,11 @@ def country2kw(row,kw):
 #~ def is_company(data):
 def PAR_model(data):
     """
-    - wer eine NISS oder Gesdos-Nr hat ist ein Klient, selbst wenn er auch eine MwSt-Nummer hat.
+    - wer eine SSIN oder Gesdos-Nr hat ist ein Klient, selbst wenn er auch eine Mwst-Nummer hat.
     - Neuzugänge (Attribut N) sind ebenfalls immer Klienten
     
     """
-    if data.get('NB2',False): # NISS
+    if data.get('NB2',False): # SSIN
         return Client
     if data.get('NB1',False): # gesdos-Nr
         return Client
@@ -363,7 +362,7 @@ class Controller:
             dblogger.warning("%s:%s : DELETE failed (does not exist)",
                 kw['alias'],kw['id'])
             return
-        msg = obj.disable_delete(ar)
+        msg = obj.disable_delete(REQUEST)
         if msg:
             dblogger.warning("%s:%s : DELETE failed: %s",kw['alias'],kw['id'],msg)
             return
@@ -446,8 +445,8 @@ class PAR(Controller):
   
     #~ def prepare_data(self,data):
         #~ if data['NB2']:
-            #~ if not is_valid_niss(data['NB2']):
-                #~ dblogger.warning("Ignored invalid NISS %s" % data['NB2'])
+            #~ if not is_valid_ssin(data['NB2']):
+                #~ dblogger.warning("Ignored invalid SSIN %s" % data['NB2'])
                 #~ data['NB2'] = ''
         #~ return data
                 
@@ -463,15 +462,13 @@ class PAR(Controller):
         
         store_date(data,obj,'DATCREA','created')
         
-        
         if data.has_key('LANGUE'):
             obj.language = isolang(data['LANGUE'])
         
-        
         #~ dblogger.info("20111223 %r",data)
         if data.has_key('ATTRIB'):
             #~ obj.newcomer = ("N" in data['ATTRIB'])
-            #~ obj.is_deprecated = ("A" in data['ATTRIB'] or "W" in data['ATTRIB'])
+            #~ obj.is_obsolete = ("A" in data['ATTRIB'] or "W" in data['ATTRIB'])
             obj.is_obsolete = ("W" in data['ATTRIB'])
         
         if issubclass(obj.__class__,Person):
@@ -488,15 +485,20 @@ class PAR(Controller):
                 mapper.update(gesdos_id='NB1')
                 if data.has_key('NB2'):
                     obj.national_id = data['NB2']
-                else:
-                    obj.national_id = str(obj.id)
+                    #~ if obj.national_id: 
+                        #~ if not is_valid_ssin(obj.national_id):
+                            #~ dblogger.info("%s : invalid SSIN %s",obj2str(obj),obj.national_id)
+                            #~ obj.national_id = None
+                #~ else 20121108:
+                    #~ obj.national_id = str(obj.id)
                     #~ if obj.is_deprecated:
                         #~ obj.national_id += ' (A)'
                 if data.has_key('ATTRIB') and "N" in data['ATTRIB']:
                     obj.client_state = pcsw.ClientStates.newcomer
                 elif data['IDPRT'] == 'I':
                     obj.client_state = pcsw.ClientStates.former
-                elif is_valid_niss(obj.national_id):
+                #~ 
+                elif obj.national_id and is_valid_ssin(obj.national_id):
                     obj.client_state = pcsw.ClientStates.coached
                 else:
                     obj.client_state = pcsw.ClientStates.invalid
@@ -552,8 +554,8 @@ class PAR(Controller):
                         #~ obj.coach1 = None
                         try:
                             coaching = pcsw.Coaching.objects.get(client=obj,primary=True)
-                            coaching.delete()
                             changes.log_delete(REQUEST,coaching)
+                            coaching.delete()
                             
                         except pcsw.Coaching.DoesNotExist,e:
                             pass
